/*
 * Copyright (c) 2013, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 */
/*
 * This file is licensed according to the BSD 3-clause license as follows:
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the "Linz Center of Mechatronics GmbH" and "LCM" nor
 *       the names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL "Linz Center of Mechatronics GmbH" BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
/*
 * This file is part of X2C. http://x2c.lcm.at/
 * $LastChangedRevision: 3207 $
 */
/* USERCODE-BEGIN:Description                                                                                         */
/* Description: */
/* USERCODE-END:Description                                                                                           */
#include "LookupTable1D_FiP16_RAM.h"

/* all used update functions to ram for c2000                                                                         */
#if defined(__ALL_UPDATE_FUNC_2_RAM_C2000__)
    #pragma CODE_SECTION(LookupTable1D_FiP16_RAM_Update, "ramfuncs")
#endif

/* USERCODE-BEGIN:PreProcessor                                                                                        */
/* Inputs */
#define IN_X        (*pTLookupTable1D_FiP16_RAM->x)

/* Outputs */
#define OUT         (pTLookupTable1D_FiP16_RAM->Out)

/* Parameters */
#define TABLE_DATA   (pTLookupTable1D_FiP16_RAM->Table)

#define SFR_X        (pTLookupTable1D_FiP16_RAM->sfrX)
#define MASK_X       (pTLookupTable1D_FiP16_RAM->maskX)
#define IDX_OFFSET_X (pTLookupTable1D_FiP16_RAM->idxOffsetX)
#define MIN_X        (pTLookupTable1D_FiP16_RAM->minX)
#define MAX_X        (pTLookupTable1D_FiP16_RAM->maxX)
#define GAIN_X       (pTLookupTable1D_FiP16_RAM->gainX)
#define GAIN_X_SFR   (pTLookupTable1D_FiP16_RAM->gainXsfr)
#define OFFSET_X     (pTLookupTable1D_FiP16_RAM->offsetX)

/* USERCODE-END:PreProcessor                                                                                          */

/**********************************************************************************************************************/
/** Update                                                                                                           **/
/**********************************************************************************************************************/
void LookupTable1D_FiP16_RAM_Update(LOOKUPTABLE1D_FIP16_RAM *pTLookupTable1D_FiP16_RAM)
{
/* USERCODE-BEGIN:UpdateFnc                                                                                           */
    int32 tmp;
    uint16 idxx;
    int16 fact, factx, deltax;
    int16 inx;

    /** - check input boundaries */
    if (IN_X < MIN_X)
    {
        /* input below lower boundary -> cutoff */
        inx = -INT16_MAX;
    }
    else if (IN_X > MAX_X)
    {
        /* input above higher boundary -> cutoff */
        inx = INT16_MAX;
    }
    else
    {
        /* input within boundaries -> input scaling */
        tmp = ((int32)IN_X - (int32)OFFSET_X);
        inx = ((int32)tmp * (int32)GAIN_X) >> GAIN_X_SFR;
    }

    /** - calculate table index */
    idxx = (inx >> SFR_X) + IDX_OFFSET_X;                   /*  x */

    /** - calculate fractual part */
    deltax = inx & MASK_X;                                  /* dx */

    /** - calculate value at lattice points */
    fact  = TABLE_DATA[idxx];                               /* f(x) */
    factx = TABLE_DATA[idxx + 1];                           /* f(x+1) */

    /** - linear interpolation */
    tmp = ((int32)(factx - fact) * (int32)deltax) >> SFR_X; /* dx*(f(x+1) - f(x)) */
    tmp = fact + tmp;                                       /* f(x) + dx*(f(x+1) - f(x)) */

    OUT = (int16)tmp;

/* USERCODE-END:UpdateFnc                                                                                             */

}

/**********************************************************************************************************************/
/** Initialization                                                                                                   **/
/**********************************************************************************************************************/
void LookupTable1D_FiP16_RAM_Init(LOOKUPTABLE1D_FIP16_RAM *pTLookupTable1D_FiP16_RAM)
{
    pTLookupTable1D_FiP16_RAM->ID = LOOKUPTABLE1D_FIP16_RAM_ID;
    pTLookupTable1D_FiP16_RAM->Out = 0;
/* USERCODE-BEGIN:InitFnc                                                                                             */
/* USERCODE-END:InitFnc                                                                                               */
}

/**********************************************************************************************************************/
/** Load block data                                                                                                  **/
/**********************************************************************************************************************/
uint8 LookupTable1D_FiP16_RAM_Load(const LOOKUPTABLE1D_FIP16_RAM *pTLookupTable1D_FiP16_RAM, uint8 data[], uint16 *dataLength, uint16 maxSize)
{
    uint8 error = (uint8)0;
    if ((uint16)528 > maxSize)
    {
        error = (uint8)1;
    }
    else
    {
        data[0] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[0] & 0x00FF);
        data[1] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[0] >> 8) & 0x00FF);
        data[2] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[1] & 0x00FF);
        data[3] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[1] >> 8) & 0x00FF);
        data[4] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[2] & 0x00FF);
        data[5] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[2] >> 8) & 0x00FF);
        data[6] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[3] & 0x00FF);
        data[7] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[3] >> 8) & 0x00FF);
        data[8] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[4] & 0x00FF);
        data[9] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[4] >> 8) & 0x00FF);
        data[10] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[5] & 0x00FF);
        data[11] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[5] >> 8) & 0x00FF);
        data[12] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[6] & 0x00FF);
        data[13] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[6] >> 8) & 0x00FF);
        data[14] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[7] & 0x00FF);
        data[15] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[7] >> 8) & 0x00FF);
        data[16] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[8] & 0x00FF);
        data[17] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[8] >> 8) & 0x00FF);
        data[18] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[9] & 0x00FF);
        data[19] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[9] >> 8) & 0x00FF);
        data[20] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[10] & 0x00FF);
        data[21] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[10] >> 8) & 0x00FF);
        data[22] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[11] & 0x00FF);
        data[23] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[11] >> 8) & 0x00FF);
        data[24] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[12] & 0x00FF);
        data[25] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[12] >> 8) & 0x00FF);
        data[26] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[13] & 0x00FF);
        data[27] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[13] >> 8) & 0x00FF);
        data[28] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[14] & 0x00FF);
        data[29] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[14] >> 8) & 0x00FF);
        data[30] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[15] & 0x00FF);
        data[31] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[15] >> 8) & 0x00FF);
        data[32] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[16] & 0x00FF);
        data[33] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[16] >> 8) & 0x00FF);
        data[34] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[17] & 0x00FF);
        data[35] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[17] >> 8) & 0x00FF);
        data[36] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[18] & 0x00FF);
        data[37] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[18] >> 8) & 0x00FF);
        data[38] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[19] & 0x00FF);
        data[39] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[19] >> 8) & 0x00FF);
        data[40] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[20] & 0x00FF);
        data[41] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[20] >> 8) & 0x00FF);
        data[42] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[21] & 0x00FF);
        data[43] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[21] >> 8) & 0x00FF);
        data[44] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[22] & 0x00FF);
        data[45] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[22] >> 8) & 0x00FF);
        data[46] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[23] & 0x00FF);
        data[47] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[23] >> 8) & 0x00FF);
        data[48] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[24] & 0x00FF);
        data[49] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[24] >> 8) & 0x00FF);
        data[50] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[25] & 0x00FF);
        data[51] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[25] >> 8) & 0x00FF);
        data[52] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[26] & 0x00FF);
        data[53] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[26] >> 8) & 0x00FF);
        data[54] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[27] & 0x00FF);
        data[55] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[27] >> 8) & 0x00FF);
        data[56] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[28] & 0x00FF);
        data[57] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[28] >> 8) & 0x00FF);
        data[58] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[29] & 0x00FF);
        data[59] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[29] >> 8) & 0x00FF);
        data[60] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[30] & 0x00FF);
        data[61] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[30] >> 8) & 0x00FF);
        data[62] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[31] & 0x00FF);
        data[63] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[31] >> 8) & 0x00FF);
        data[64] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[32] & 0x00FF);
        data[65] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[32] >> 8) & 0x00FF);
        data[66] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[33] & 0x00FF);
        data[67] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[33] >> 8) & 0x00FF);
        data[68] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[34] & 0x00FF);
        data[69] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[34] >> 8) & 0x00FF);
        data[70] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[35] & 0x00FF);
        data[71] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[35] >> 8) & 0x00FF);
        data[72] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[36] & 0x00FF);
        data[73] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[36] >> 8) & 0x00FF);
        data[74] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[37] & 0x00FF);
        data[75] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[37] >> 8) & 0x00FF);
        data[76] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[38] & 0x00FF);
        data[77] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[38] >> 8) & 0x00FF);
        data[78] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[39] & 0x00FF);
        data[79] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[39] >> 8) & 0x00FF);
        data[80] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[40] & 0x00FF);
        data[81] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[40] >> 8) & 0x00FF);
        data[82] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[41] & 0x00FF);
        data[83] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[41] >> 8) & 0x00FF);
        data[84] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[42] & 0x00FF);
        data[85] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[42] >> 8) & 0x00FF);
        data[86] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[43] & 0x00FF);
        data[87] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[43] >> 8) & 0x00FF);
        data[88] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[44] & 0x00FF);
        data[89] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[44] >> 8) & 0x00FF);
        data[90] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[45] & 0x00FF);
        data[91] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[45] >> 8) & 0x00FF);
        data[92] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[46] & 0x00FF);
        data[93] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[46] >> 8) & 0x00FF);
        data[94] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[47] & 0x00FF);
        data[95] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[47] >> 8) & 0x00FF);
        data[96] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[48] & 0x00FF);
        data[97] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[48] >> 8) & 0x00FF);
        data[98] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[49] & 0x00FF);
        data[99] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[49] >> 8) & 0x00FF);
        data[100] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[50] & 0x00FF);
        data[101] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[50] >> 8) & 0x00FF);
        data[102] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[51] & 0x00FF);
        data[103] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[51] >> 8) & 0x00FF);
        data[104] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[52] & 0x00FF);
        data[105] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[52] >> 8) & 0x00FF);
        data[106] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[53] & 0x00FF);
        data[107] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[53] >> 8) & 0x00FF);
        data[108] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[54] & 0x00FF);
        data[109] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[54] >> 8) & 0x00FF);
        data[110] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[55] & 0x00FF);
        data[111] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[55] >> 8) & 0x00FF);
        data[112] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[56] & 0x00FF);
        data[113] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[56] >> 8) & 0x00FF);
        data[114] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[57] & 0x00FF);
        data[115] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[57] >> 8) & 0x00FF);
        data[116] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[58] & 0x00FF);
        data[117] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[58] >> 8) & 0x00FF);
        data[118] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[59] & 0x00FF);
        data[119] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[59] >> 8) & 0x00FF);
        data[120] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[60] & 0x00FF);
        data[121] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[60] >> 8) & 0x00FF);
        data[122] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[61] & 0x00FF);
        data[123] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[61] >> 8) & 0x00FF);
        data[124] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[62] & 0x00FF);
        data[125] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[62] >> 8) & 0x00FF);
        data[126] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[63] & 0x00FF);
        data[127] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[63] >> 8) & 0x00FF);
        data[128] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[64] & 0x00FF);
        data[129] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[64] >> 8) & 0x00FF);
        data[130] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[65] & 0x00FF);
        data[131] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[65] >> 8) & 0x00FF);
        data[132] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[66] & 0x00FF);
        data[133] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[66] >> 8) & 0x00FF);
        data[134] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[67] & 0x00FF);
        data[135] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[67] >> 8) & 0x00FF);
        data[136] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[68] & 0x00FF);
        data[137] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[68] >> 8) & 0x00FF);
        data[138] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[69] & 0x00FF);
        data[139] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[69] >> 8) & 0x00FF);
        data[140] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[70] & 0x00FF);
        data[141] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[70] >> 8) & 0x00FF);
        data[142] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[71] & 0x00FF);
        data[143] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[71] >> 8) & 0x00FF);
        data[144] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[72] & 0x00FF);
        data[145] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[72] >> 8) & 0x00FF);
        data[146] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[73] & 0x00FF);
        data[147] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[73] >> 8) & 0x00FF);
        data[148] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[74] & 0x00FF);
        data[149] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[74] >> 8) & 0x00FF);
        data[150] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[75] & 0x00FF);
        data[151] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[75] >> 8) & 0x00FF);
        data[152] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[76] & 0x00FF);
        data[153] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[76] >> 8) & 0x00FF);
        data[154] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[77] & 0x00FF);
        data[155] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[77] >> 8) & 0x00FF);
        data[156] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[78] & 0x00FF);
        data[157] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[78] >> 8) & 0x00FF);
        data[158] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[79] & 0x00FF);
        data[159] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[79] >> 8) & 0x00FF);
        data[160] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[80] & 0x00FF);
        data[161] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[80] >> 8) & 0x00FF);
        data[162] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[81] & 0x00FF);
        data[163] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[81] >> 8) & 0x00FF);
        data[164] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[82] & 0x00FF);
        data[165] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[82] >> 8) & 0x00FF);
        data[166] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[83] & 0x00FF);
        data[167] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[83] >> 8) & 0x00FF);
        data[168] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[84] & 0x00FF);
        data[169] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[84] >> 8) & 0x00FF);
        data[170] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[85] & 0x00FF);
        data[171] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[85] >> 8) & 0x00FF);
        data[172] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[86] & 0x00FF);
        data[173] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[86] >> 8) & 0x00FF);
        data[174] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[87] & 0x00FF);
        data[175] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[87] >> 8) & 0x00FF);
        data[176] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[88] & 0x00FF);
        data[177] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[88] >> 8) & 0x00FF);
        data[178] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[89] & 0x00FF);
        data[179] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[89] >> 8) & 0x00FF);
        data[180] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[90] & 0x00FF);
        data[181] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[90] >> 8) & 0x00FF);
        data[182] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[91] & 0x00FF);
        data[183] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[91] >> 8) & 0x00FF);
        data[184] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[92] & 0x00FF);
        data[185] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[92] >> 8) & 0x00FF);
        data[186] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[93] & 0x00FF);
        data[187] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[93] >> 8) & 0x00FF);
        data[188] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[94] & 0x00FF);
        data[189] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[94] >> 8) & 0x00FF);
        data[190] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[95] & 0x00FF);
        data[191] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[95] >> 8) & 0x00FF);
        data[192] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[96] & 0x00FF);
        data[193] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[96] >> 8) & 0x00FF);
        data[194] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[97] & 0x00FF);
        data[195] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[97] >> 8) & 0x00FF);
        data[196] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[98] & 0x00FF);
        data[197] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[98] >> 8) & 0x00FF);
        data[198] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[99] & 0x00FF);
        data[199] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[99] >> 8) & 0x00FF);
        data[200] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[100] & 0x00FF);
        data[201] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[100] >> 8) & 0x00FF);
        data[202] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[101] & 0x00FF);
        data[203] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[101] >> 8) & 0x00FF);
        data[204] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[102] & 0x00FF);
        data[205] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[102] >> 8) & 0x00FF);
        data[206] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[103] & 0x00FF);
        data[207] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[103] >> 8) & 0x00FF);
        data[208] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[104] & 0x00FF);
        data[209] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[104] >> 8) & 0x00FF);
        data[210] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[105] & 0x00FF);
        data[211] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[105] >> 8) & 0x00FF);
        data[212] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[106] & 0x00FF);
        data[213] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[106] >> 8) & 0x00FF);
        data[214] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[107] & 0x00FF);
        data[215] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[107] >> 8) & 0x00FF);
        data[216] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[108] & 0x00FF);
        data[217] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[108] >> 8) & 0x00FF);
        data[218] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[109] & 0x00FF);
        data[219] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[109] >> 8) & 0x00FF);
        data[220] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[110] & 0x00FF);
        data[221] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[110] >> 8) & 0x00FF);
        data[222] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[111] & 0x00FF);
        data[223] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[111] >> 8) & 0x00FF);
        data[224] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[112] & 0x00FF);
        data[225] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[112] >> 8) & 0x00FF);
        data[226] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[113] & 0x00FF);
        data[227] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[113] >> 8) & 0x00FF);
        data[228] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[114] & 0x00FF);
        data[229] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[114] >> 8) & 0x00FF);
        data[230] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[115] & 0x00FF);
        data[231] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[115] >> 8) & 0x00FF);
        data[232] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[116] & 0x00FF);
        data[233] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[116] >> 8) & 0x00FF);
        data[234] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[117] & 0x00FF);
        data[235] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[117] >> 8) & 0x00FF);
        data[236] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[118] & 0x00FF);
        data[237] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[118] >> 8) & 0x00FF);
        data[238] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[119] & 0x00FF);
        data[239] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[119] >> 8) & 0x00FF);
        data[240] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[120] & 0x00FF);
        data[241] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[120] >> 8) & 0x00FF);
        data[242] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[121] & 0x00FF);
        data[243] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[121] >> 8) & 0x00FF);
        data[244] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[122] & 0x00FF);
        data[245] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[122] >> 8) & 0x00FF);
        data[246] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[123] & 0x00FF);
        data[247] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[123] >> 8) & 0x00FF);
        data[248] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[124] & 0x00FF);
        data[249] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[124] >> 8) & 0x00FF);
        data[250] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[125] & 0x00FF);
        data[251] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[125] >> 8) & 0x00FF);
        data[252] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[126] & 0x00FF);
        data[253] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[126] >> 8) & 0x00FF);
        data[254] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[127] & 0x00FF);
        data[255] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[127] >> 8) & 0x00FF);
        data[256] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[128] & 0x00FF);
        data[257] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[128] >> 8) & 0x00FF);
        data[258] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[129] & 0x00FF);
        data[259] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[129] >> 8) & 0x00FF);
        data[260] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[130] & 0x00FF);
        data[261] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[130] >> 8) & 0x00FF);
        data[262] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[131] & 0x00FF);
        data[263] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[131] >> 8) & 0x00FF);
        data[264] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[132] & 0x00FF);
        data[265] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[132] >> 8) & 0x00FF);
        data[266] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[133] & 0x00FF);
        data[267] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[133] >> 8) & 0x00FF);
        data[268] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[134] & 0x00FF);
        data[269] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[134] >> 8) & 0x00FF);
        data[270] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[135] & 0x00FF);
        data[271] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[135] >> 8) & 0x00FF);
        data[272] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[136] & 0x00FF);
        data[273] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[136] >> 8) & 0x00FF);
        data[274] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[137] & 0x00FF);
        data[275] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[137] >> 8) & 0x00FF);
        data[276] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[138] & 0x00FF);
        data[277] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[138] >> 8) & 0x00FF);
        data[278] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[139] & 0x00FF);
        data[279] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[139] >> 8) & 0x00FF);
        data[280] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[140] & 0x00FF);
        data[281] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[140] >> 8) & 0x00FF);
        data[282] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[141] & 0x00FF);
        data[283] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[141] >> 8) & 0x00FF);
        data[284] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[142] & 0x00FF);
        data[285] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[142] >> 8) & 0x00FF);
        data[286] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[143] & 0x00FF);
        data[287] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[143] >> 8) & 0x00FF);
        data[288] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[144] & 0x00FF);
        data[289] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[144] >> 8) & 0x00FF);
        data[290] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[145] & 0x00FF);
        data[291] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[145] >> 8) & 0x00FF);
        data[292] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[146] & 0x00FF);
        data[293] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[146] >> 8) & 0x00FF);
        data[294] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[147] & 0x00FF);
        data[295] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[147] >> 8) & 0x00FF);
        data[296] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[148] & 0x00FF);
        data[297] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[148] >> 8) & 0x00FF);
        data[298] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[149] & 0x00FF);
        data[299] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[149] >> 8) & 0x00FF);
        data[300] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[150] & 0x00FF);
        data[301] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[150] >> 8) & 0x00FF);
        data[302] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[151] & 0x00FF);
        data[303] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[151] >> 8) & 0x00FF);
        data[304] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[152] & 0x00FF);
        data[305] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[152] >> 8) & 0x00FF);
        data[306] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[153] & 0x00FF);
        data[307] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[153] >> 8) & 0x00FF);
        data[308] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[154] & 0x00FF);
        data[309] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[154] >> 8) & 0x00FF);
        data[310] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[155] & 0x00FF);
        data[311] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[155] >> 8) & 0x00FF);
        data[312] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[156] & 0x00FF);
        data[313] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[156] >> 8) & 0x00FF);
        data[314] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[157] & 0x00FF);
        data[315] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[157] >> 8) & 0x00FF);
        data[316] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[158] & 0x00FF);
        data[317] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[158] >> 8) & 0x00FF);
        data[318] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[159] & 0x00FF);
        data[319] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[159] >> 8) & 0x00FF);
        data[320] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[160] & 0x00FF);
        data[321] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[160] >> 8) & 0x00FF);
        data[322] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[161] & 0x00FF);
        data[323] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[161] >> 8) & 0x00FF);
        data[324] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[162] & 0x00FF);
        data[325] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[162] >> 8) & 0x00FF);
        data[326] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[163] & 0x00FF);
        data[327] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[163] >> 8) & 0x00FF);
        data[328] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[164] & 0x00FF);
        data[329] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[164] >> 8) & 0x00FF);
        data[330] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[165] & 0x00FF);
        data[331] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[165] >> 8) & 0x00FF);
        data[332] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[166] & 0x00FF);
        data[333] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[166] >> 8) & 0x00FF);
        data[334] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[167] & 0x00FF);
        data[335] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[167] >> 8) & 0x00FF);
        data[336] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[168] & 0x00FF);
        data[337] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[168] >> 8) & 0x00FF);
        data[338] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[169] & 0x00FF);
        data[339] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[169] >> 8) & 0x00FF);
        data[340] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[170] & 0x00FF);
        data[341] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[170] >> 8) & 0x00FF);
        data[342] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[171] & 0x00FF);
        data[343] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[171] >> 8) & 0x00FF);
        data[344] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[172] & 0x00FF);
        data[345] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[172] >> 8) & 0x00FF);
        data[346] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[173] & 0x00FF);
        data[347] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[173] >> 8) & 0x00FF);
        data[348] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[174] & 0x00FF);
        data[349] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[174] >> 8) & 0x00FF);
        data[350] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[175] & 0x00FF);
        data[351] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[175] >> 8) & 0x00FF);
        data[352] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[176] & 0x00FF);
        data[353] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[176] >> 8) & 0x00FF);
        data[354] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[177] & 0x00FF);
        data[355] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[177] >> 8) & 0x00FF);
        data[356] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[178] & 0x00FF);
        data[357] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[178] >> 8) & 0x00FF);
        data[358] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[179] & 0x00FF);
        data[359] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[179] >> 8) & 0x00FF);
        data[360] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[180] & 0x00FF);
        data[361] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[180] >> 8) & 0x00FF);
        data[362] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[181] & 0x00FF);
        data[363] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[181] >> 8) & 0x00FF);
        data[364] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[182] & 0x00FF);
        data[365] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[182] >> 8) & 0x00FF);
        data[366] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[183] & 0x00FF);
        data[367] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[183] >> 8) & 0x00FF);
        data[368] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[184] & 0x00FF);
        data[369] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[184] >> 8) & 0x00FF);
        data[370] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[185] & 0x00FF);
        data[371] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[185] >> 8) & 0x00FF);
        data[372] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[186] & 0x00FF);
        data[373] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[186] >> 8) & 0x00FF);
        data[374] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[187] & 0x00FF);
        data[375] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[187] >> 8) & 0x00FF);
        data[376] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[188] & 0x00FF);
        data[377] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[188] >> 8) & 0x00FF);
        data[378] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[189] & 0x00FF);
        data[379] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[189] >> 8) & 0x00FF);
        data[380] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[190] & 0x00FF);
        data[381] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[190] >> 8) & 0x00FF);
        data[382] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[191] & 0x00FF);
        data[383] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[191] >> 8) & 0x00FF);
        data[384] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[192] & 0x00FF);
        data[385] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[192] >> 8) & 0x00FF);
        data[386] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[193] & 0x00FF);
        data[387] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[193] >> 8) & 0x00FF);
        data[388] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[194] & 0x00FF);
        data[389] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[194] >> 8) & 0x00FF);
        data[390] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[195] & 0x00FF);
        data[391] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[195] >> 8) & 0x00FF);
        data[392] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[196] & 0x00FF);
        data[393] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[196] >> 8) & 0x00FF);
        data[394] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[197] & 0x00FF);
        data[395] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[197] >> 8) & 0x00FF);
        data[396] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[198] & 0x00FF);
        data[397] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[198] >> 8) & 0x00FF);
        data[398] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[199] & 0x00FF);
        data[399] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[199] >> 8) & 0x00FF);
        data[400] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[200] & 0x00FF);
        data[401] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[200] >> 8) & 0x00FF);
        data[402] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[201] & 0x00FF);
        data[403] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[201] >> 8) & 0x00FF);
        data[404] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[202] & 0x00FF);
        data[405] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[202] >> 8) & 0x00FF);
        data[406] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[203] & 0x00FF);
        data[407] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[203] >> 8) & 0x00FF);
        data[408] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[204] & 0x00FF);
        data[409] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[204] >> 8) & 0x00FF);
        data[410] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[205] & 0x00FF);
        data[411] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[205] >> 8) & 0x00FF);
        data[412] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[206] & 0x00FF);
        data[413] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[206] >> 8) & 0x00FF);
        data[414] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[207] & 0x00FF);
        data[415] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[207] >> 8) & 0x00FF);
        data[416] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[208] & 0x00FF);
        data[417] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[208] >> 8) & 0x00FF);
        data[418] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[209] & 0x00FF);
        data[419] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[209] >> 8) & 0x00FF);
        data[420] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[210] & 0x00FF);
        data[421] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[210] >> 8) & 0x00FF);
        data[422] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[211] & 0x00FF);
        data[423] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[211] >> 8) & 0x00FF);
        data[424] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[212] & 0x00FF);
        data[425] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[212] >> 8) & 0x00FF);
        data[426] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[213] & 0x00FF);
        data[427] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[213] >> 8) & 0x00FF);
        data[428] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[214] & 0x00FF);
        data[429] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[214] >> 8) & 0x00FF);
        data[430] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[215] & 0x00FF);
        data[431] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[215] >> 8) & 0x00FF);
        data[432] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[216] & 0x00FF);
        data[433] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[216] >> 8) & 0x00FF);
        data[434] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[217] & 0x00FF);
        data[435] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[217] >> 8) & 0x00FF);
        data[436] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[218] & 0x00FF);
        data[437] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[218] >> 8) & 0x00FF);
        data[438] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[219] & 0x00FF);
        data[439] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[219] >> 8) & 0x00FF);
        data[440] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[220] & 0x00FF);
        data[441] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[220] >> 8) & 0x00FF);
        data[442] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[221] & 0x00FF);
        data[443] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[221] >> 8) & 0x00FF);
        data[444] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[222] & 0x00FF);
        data[445] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[222] >> 8) & 0x00FF);
        data[446] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[223] & 0x00FF);
        data[447] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[223] >> 8) & 0x00FF);
        data[448] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[224] & 0x00FF);
        data[449] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[224] >> 8) & 0x00FF);
        data[450] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[225] & 0x00FF);
        data[451] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[225] >> 8) & 0x00FF);
        data[452] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[226] & 0x00FF);
        data[453] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[226] >> 8) & 0x00FF);
        data[454] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[227] & 0x00FF);
        data[455] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[227] >> 8) & 0x00FF);
        data[456] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[228] & 0x00FF);
        data[457] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[228] >> 8) & 0x00FF);
        data[458] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[229] & 0x00FF);
        data[459] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[229] >> 8) & 0x00FF);
        data[460] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[230] & 0x00FF);
        data[461] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[230] >> 8) & 0x00FF);
        data[462] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[231] & 0x00FF);
        data[463] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[231] >> 8) & 0x00FF);
        data[464] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[232] & 0x00FF);
        data[465] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[232] >> 8) & 0x00FF);
        data[466] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[233] & 0x00FF);
        data[467] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[233] >> 8) & 0x00FF);
        data[468] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[234] & 0x00FF);
        data[469] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[234] >> 8) & 0x00FF);
        data[470] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[235] & 0x00FF);
        data[471] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[235] >> 8) & 0x00FF);
        data[472] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[236] & 0x00FF);
        data[473] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[236] >> 8) & 0x00FF);
        data[474] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[237] & 0x00FF);
        data[475] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[237] >> 8) & 0x00FF);
        data[476] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[238] & 0x00FF);
        data[477] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[238] >> 8) & 0x00FF);
        data[478] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[239] & 0x00FF);
        data[479] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[239] >> 8) & 0x00FF);
        data[480] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[240] & 0x00FF);
        data[481] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[240] >> 8) & 0x00FF);
        data[482] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[241] & 0x00FF);
        data[483] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[241] >> 8) & 0x00FF);
        data[484] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[242] & 0x00FF);
        data[485] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[242] >> 8) & 0x00FF);
        data[486] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[243] & 0x00FF);
        data[487] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[243] >> 8) & 0x00FF);
        data[488] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[244] & 0x00FF);
        data[489] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[244] >> 8) & 0x00FF);
        data[490] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[245] & 0x00FF);
        data[491] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[245] >> 8) & 0x00FF);
        data[492] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[246] & 0x00FF);
        data[493] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[246] >> 8) & 0x00FF);
        data[494] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[247] & 0x00FF);
        data[495] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[247] >> 8) & 0x00FF);
        data[496] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[248] & 0x00FF);
        data[497] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[248] >> 8) & 0x00FF);
        data[498] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[249] & 0x00FF);
        data[499] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[249] >> 8) & 0x00FF);
        data[500] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[250] & 0x00FF);
        data[501] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[250] >> 8) & 0x00FF);
        data[502] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[251] & 0x00FF);
        data[503] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[251] >> 8) & 0x00FF);
        data[504] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[252] & 0x00FF);
        data[505] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[252] >> 8) & 0x00FF);
        data[506] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[253] & 0x00FF);
        data[507] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[253] >> 8) & 0x00FF);
        data[508] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[254] & 0x00FF);
        data[509] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[254] >> 8) & 0x00FF);
        data[510] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[255] & 0x00FF);
        data[511] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[255] >> 8) & 0x00FF);
        data[512] = (uint8)(pTLookupTable1D_FiP16_RAM->Table[256] & 0x00FF);
        data[513] = (uint8)((pTLookupTable1D_FiP16_RAM->Table[256] >> 8) & 0x00FF);
        data[514] = (uint8)pTLookupTable1D_FiP16_RAM->sfrX;
        data[515] = (uint8)(pTLookupTable1D_FiP16_RAM->maskX & 0x00FF);
        data[516] = (uint8)((pTLookupTable1D_FiP16_RAM->maskX >> 8) & 0x00FF);
        data[517] = (uint8)(pTLookupTable1D_FiP16_RAM->idxOffsetX & 0x00FF);
        data[518] = (uint8)((pTLookupTable1D_FiP16_RAM->idxOffsetX >> 8) & 0x00FF);
        data[519] = (uint8)(pTLookupTable1D_FiP16_RAM->gainX & 0x00FF);
        data[520] = (uint8)((pTLookupTable1D_FiP16_RAM->gainX >> 8) & 0x00FF);
        data[521] = (uint8)pTLookupTable1D_FiP16_RAM->gainXsfr;
        data[522] = (uint8)(pTLookupTable1D_FiP16_RAM->offsetX & 0x00FF);
        data[523] = (uint8)((pTLookupTable1D_FiP16_RAM->offsetX >> 8) & 0x00FF);
        data[524] = (uint8)(pTLookupTable1D_FiP16_RAM->minX & 0x00FF);
        data[525] = (uint8)((pTLookupTable1D_FiP16_RAM->minX >> 8) & 0x00FF);
        data[526] = (uint8)(pTLookupTable1D_FiP16_RAM->maxX & 0x00FF);
        data[527] = (uint8)((pTLookupTable1D_FiP16_RAM->maxX >> 8) & 0x00FF);
        *dataLength = (uint16)528;
/* USERCODE-BEGIN:LoadFnc                                                                                             */
/* USERCODE-END:LoadFnc                                                                                               */
    }
    return (error);
}

/**********************************************************************************************************************/
/** Save block data                                                                                                  **/
/**********************************************************************************************************************/
uint8 LookupTable1D_FiP16_RAM_Save(LOOKUPTABLE1D_FIP16_RAM *pTLookupTable1D_FiP16_RAM, const uint8 data[], uint16 dataLength)
{
    uint8 error;

    if (dataLength != (uint16)528)
    {
        error = (uint8)1;
    }
    else
    {
        pTLookupTable1D_FiP16_RAM->Table[0] = UINT16_TO_INT16((uint16)data[0] + \
            ((uint16)data[1] << 8));
        pTLookupTable1D_FiP16_RAM->Table[1] = UINT16_TO_INT16((uint16)data[2] + \
            ((uint16)data[3] << 8));
        pTLookupTable1D_FiP16_RAM->Table[2] = UINT16_TO_INT16((uint16)data[4] + \
            ((uint16)data[5] << 8));
        pTLookupTable1D_FiP16_RAM->Table[3] = UINT16_TO_INT16((uint16)data[6] + \
            ((uint16)data[7] << 8));
        pTLookupTable1D_FiP16_RAM->Table[4] = UINT16_TO_INT16((uint16)data[8] + \
            ((uint16)data[9] << 8));
        pTLookupTable1D_FiP16_RAM->Table[5] = UINT16_TO_INT16((uint16)data[10] + \
            ((uint16)data[11] << 8));
        pTLookupTable1D_FiP16_RAM->Table[6] = UINT16_TO_INT16((uint16)data[12] + \
            ((uint16)data[13] << 8));
        pTLookupTable1D_FiP16_RAM->Table[7] = UINT16_TO_INT16((uint16)data[14] + \
            ((uint16)data[15] << 8));
        pTLookupTable1D_FiP16_RAM->Table[8] = UINT16_TO_INT16((uint16)data[16] + \
            ((uint16)data[17] << 8));
        pTLookupTable1D_FiP16_RAM->Table[9] = UINT16_TO_INT16((uint16)data[18] + \
            ((uint16)data[19] << 8));
        pTLookupTable1D_FiP16_RAM->Table[10] = UINT16_TO_INT16((uint16)data[20] + \
            ((uint16)data[21] << 8));
        pTLookupTable1D_FiP16_RAM->Table[11] = UINT16_TO_INT16((uint16)data[22] + \
            ((uint16)data[23] << 8));
        pTLookupTable1D_FiP16_RAM->Table[12] = UINT16_TO_INT16((uint16)data[24] + \
            ((uint16)data[25] << 8));
        pTLookupTable1D_FiP16_RAM->Table[13] = UINT16_TO_INT16((uint16)data[26] + \
            ((uint16)data[27] << 8));
        pTLookupTable1D_FiP16_RAM->Table[14] = UINT16_TO_INT16((uint16)data[28] + \
            ((uint16)data[29] << 8));
        pTLookupTable1D_FiP16_RAM->Table[15] = UINT16_TO_INT16((uint16)data[30] + \
            ((uint16)data[31] << 8));
        pTLookupTable1D_FiP16_RAM->Table[16] = UINT16_TO_INT16((uint16)data[32] + \
            ((uint16)data[33] << 8));
        pTLookupTable1D_FiP16_RAM->Table[17] = UINT16_TO_INT16((uint16)data[34] + \
            ((uint16)data[35] << 8));
        pTLookupTable1D_FiP16_RAM->Table[18] = UINT16_TO_INT16((uint16)data[36] + \
            ((uint16)data[37] << 8));
        pTLookupTable1D_FiP16_RAM->Table[19] = UINT16_TO_INT16((uint16)data[38] + \
            ((uint16)data[39] << 8));
        pTLookupTable1D_FiP16_RAM->Table[20] = UINT16_TO_INT16((uint16)data[40] + \
            ((uint16)data[41] << 8));
        pTLookupTable1D_FiP16_RAM->Table[21] = UINT16_TO_INT16((uint16)data[42] + \
            ((uint16)data[43] << 8));
        pTLookupTable1D_FiP16_RAM->Table[22] = UINT16_TO_INT16((uint16)data[44] + \
            ((uint16)data[45] << 8));
        pTLookupTable1D_FiP16_RAM->Table[23] = UINT16_TO_INT16((uint16)data[46] + \
            ((uint16)data[47] << 8));
        pTLookupTable1D_FiP16_RAM->Table[24] = UINT16_TO_INT16((uint16)data[48] + \
            ((uint16)data[49] << 8));
        pTLookupTable1D_FiP16_RAM->Table[25] = UINT16_TO_INT16((uint16)data[50] + \
            ((uint16)data[51] << 8));
        pTLookupTable1D_FiP16_RAM->Table[26] = UINT16_TO_INT16((uint16)data[52] + \
            ((uint16)data[53] << 8));
        pTLookupTable1D_FiP16_RAM->Table[27] = UINT16_TO_INT16((uint16)data[54] + \
            ((uint16)data[55] << 8));
        pTLookupTable1D_FiP16_RAM->Table[28] = UINT16_TO_INT16((uint16)data[56] + \
            ((uint16)data[57] << 8));
        pTLookupTable1D_FiP16_RAM->Table[29] = UINT16_TO_INT16((uint16)data[58] + \
            ((uint16)data[59] << 8));
        pTLookupTable1D_FiP16_RAM->Table[30] = UINT16_TO_INT16((uint16)data[60] + \
            ((uint16)data[61] << 8));
        pTLookupTable1D_FiP16_RAM->Table[31] = UINT16_TO_INT16((uint16)data[62] + \
            ((uint16)data[63] << 8));
        pTLookupTable1D_FiP16_RAM->Table[32] = UINT16_TO_INT16((uint16)data[64] + \
            ((uint16)data[65] << 8));
        pTLookupTable1D_FiP16_RAM->Table[33] = UINT16_TO_INT16((uint16)data[66] + \
            ((uint16)data[67] << 8));
        pTLookupTable1D_FiP16_RAM->Table[34] = UINT16_TO_INT16((uint16)data[68] + \
            ((uint16)data[69] << 8));
        pTLookupTable1D_FiP16_RAM->Table[35] = UINT16_TO_INT16((uint16)data[70] + \
            ((uint16)data[71] << 8));
        pTLookupTable1D_FiP16_RAM->Table[36] = UINT16_TO_INT16((uint16)data[72] + \
            ((uint16)data[73] << 8));
        pTLookupTable1D_FiP16_RAM->Table[37] = UINT16_TO_INT16((uint16)data[74] + \
            ((uint16)data[75] << 8));
        pTLookupTable1D_FiP16_RAM->Table[38] = UINT16_TO_INT16((uint16)data[76] + \
            ((uint16)data[77] << 8));
        pTLookupTable1D_FiP16_RAM->Table[39] = UINT16_TO_INT16((uint16)data[78] + \
            ((uint16)data[79] << 8));
        pTLookupTable1D_FiP16_RAM->Table[40] = UINT16_TO_INT16((uint16)data[80] + \
            ((uint16)data[81] << 8));
        pTLookupTable1D_FiP16_RAM->Table[41] = UINT16_TO_INT16((uint16)data[82] + \
            ((uint16)data[83] << 8));
        pTLookupTable1D_FiP16_RAM->Table[42] = UINT16_TO_INT16((uint16)data[84] + \
            ((uint16)data[85] << 8));
        pTLookupTable1D_FiP16_RAM->Table[43] = UINT16_TO_INT16((uint16)data[86] + \
            ((uint16)data[87] << 8));
        pTLookupTable1D_FiP16_RAM->Table[44] = UINT16_TO_INT16((uint16)data[88] + \
            ((uint16)data[89] << 8));
        pTLookupTable1D_FiP16_RAM->Table[45] = UINT16_TO_INT16((uint16)data[90] + \
            ((uint16)data[91] << 8));
        pTLookupTable1D_FiP16_RAM->Table[46] = UINT16_TO_INT16((uint16)data[92] + \
            ((uint16)data[93] << 8));
        pTLookupTable1D_FiP16_RAM->Table[47] = UINT16_TO_INT16((uint16)data[94] + \
            ((uint16)data[95] << 8));
        pTLookupTable1D_FiP16_RAM->Table[48] = UINT16_TO_INT16((uint16)data[96] + \
            ((uint16)data[97] << 8));
        pTLookupTable1D_FiP16_RAM->Table[49] = UINT16_TO_INT16((uint16)data[98] + \
            ((uint16)data[99] << 8));
        pTLookupTable1D_FiP16_RAM->Table[50] = UINT16_TO_INT16((uint16)data[100] + \
            ((uint16)data[101] << 8));
        pTLookupTable1D_FiP16_RAM->Table[51] = UINT16_TO_INT16((uint16)data[102] + \
            ((uint16)data[103] << 8));
        pTLookupTable1D_FiP16_RAM->Table[52] = UINT16_TO_INT16((uint16)data[104] + \
            ((uint16)data[105] << 8));
        pTLookupTable1D_FiP16_RAM->Table[53] = UINT16_TO_INT16((uint16)data[106] + \
            ((uint16)data[107] << 8));
        pTLookupTable1D_FiP16_RAM->Table[54] = UINT16_TO_INT16((uint16)data[108] + \
            ((uint16)data[109] << 8));
        pTLookupTable1D_FiP16_RAM->Table[55] = UINT16_TO_INT16((uint16)data[110] + \
            ((uint16)data[111] << 8));
        pTLookupTable1D_FiP16_RAM->Table[56] = UINT16_TO_INT16((uint16)data[112] + \
            ((uint16)data[113] << 8));
        pTLookupTable1D_FiP16_RAM->Table[57] = UINT16_TO_INT16((uint16)data[114] + \
            ((uint16)data[115] << 8));
        pTLookupTable1D_FiP16_RAM->Table[58] = UINT16_TO_INT16((uint16)data[116] + \
            ((uint16)data[117] << 8));
        pTLookupTable1D_FiP16_RAM->Table[59] = UINT16_TO_INT16((uint16)data[118] + \
            ((uint16)data[119] << 8));
        pTLookupTable1D_FiP16_RAM->Table[60] = UINT16_TO_INT16((uint16)data[120] + \
            ((uint16)data[121] << 8));
        pTLookupTable1D_FiP16_RAM->Table[61] = UINT16_TO_INT16((uint16)data[122] + \
            ((uint16)data[123] << 8));
        pTLookupTable1D_FiP16_RAM->Table[62] = UINT16_TO_INT16((uint16)data[124] + \
            ((uint16)data[125] << 8));
        pTLookupTable1D_FiP16_RAM->Table[63] = UINT16_TO_INT16((uint16)data[126] + \
            ((uint16)data[127] << 8));
        pTLookupTable1D_FiP16_RAM->Table[64] = UINT16_TO_INT16((uint16)data[128] + \
            ((uint16)data[129] << 8));
        pTLookupTable1D_FiP16_RAM->Table[65] = UINT16_TO_INT16((uint16)data[130] + \
            ((uint16)data[131] << 8));
        pTLookupTable1D_FiP16_RAM->Table[66] = UINT16_TO_INT16((uint16)data[132] + \
            ((uint16)data[133] << 8));
        pTLookupTable1D_FiP16_RAM->Table[67] = UINT16_TO_INT16((uint16)data[134] + \
            ((uint16)data[135] << 8));
        pTLookupTable1D_FiP16_RAM->Table[68] = UINT16_TO_INT16((uint16)data[136] + \
            ((uint16)data[137] << 8));
        pTLookupTable1D_FiP16_RAM->Table[69] = UINT16_TO_INT16((uint16)data[138] + \
            ((uint16)data[139] << 8));
        pTLookupTable1D_FiP16_RAM->Table[70] = UINT16_TO_INT16((uint16)data[140] + \
            ((uint16)data[141] << 8));
        pTLookupTable1D_FiP16_RAM->Table[71] = UINT16_TO_INT16((uint16)data[142] + \
            ((uint16)data[143] << 8));
        pTLookupTable1D_FiP16_RAM->Table[72] = UINT16_TO_INT16((uint16)data[144] + \
            ((uint16)data[145] << 8));
        pTLookupTable1D_FiP16_RAM->Table[73] = UINT16_TO_INT16((uint16)data[146] + \
            ((uint16)data[147] << 8));
        pTLookupTable1D_FiP16_RAM->Table[74] = UINT16_TO_INT16((uint16)data[148] + \
            ((uint16)data[149] << 8));
        pTLookupTable1D_FiP16_RAM->Table[75] = UINT16_TO_INT16((uint16)data[150] + \
            ((uint16)data[151] << 8));
        pTLookupTable1D_FiP16_RAM->Table[76] = UINT16_TO_INT16((uint16)data[152] + \
            ((uint16)data[153] << 8));
        pTLookupTable1D_FiP16_RAM->Table[77] = UINT16_TO_INT16((uint16)data[154] + \
            ((uint16)data[155] << 8));
        pTLookupTable1D_FiP16_RAM->Table[78] = UINT16_TO_INT16((uint16)data[156] + \
            ((uint16)data[157] << 8));
        pTLookupTable1D_FiP16_RAM->Table[79] = UINT16_TO_INT16((uint16)data[158] + \
            ((uint16)data[159] << 8));
        pTLookupTable1D_FiP16_RAM->Table[80] = UINT16_TO_INT16((uint16)data[160] + \
            ((uint16)data[161] << 8));
        pTLookupTable1D_FiP16_RAM->Table[81] = UINT16_TO_INT16((uint16)data[162] + \
            ((uint16)data[163] << 8));
        pTLookupTable1D_FiP16_RAM->Table[82] = UINT16_TO_INT16((uint16)data[164] + \
            ((uint16)data[165] << 8));
        pTLookupTable1D_FiP16_RAM->Table[83] = UINT16_TO_INT16((uint16)data[166] + \
            ((uint16)data[167] << 8));
        pTLookupTable1D_FiP16_RAM->Table[84] = UINT16_TO_INT16((uint16)data[168] + \
            ((uint16)data[169] << 8));
        pTLookupTable1D_FiP16_RAM->Table[85] = UINT16_TO_INT16((uint16)data[170] + \
            ((uint16)data[171] << 8));
        pTLookupTable1D_FiP16_RAM->Table[86] = UINT16_TO_INT16((uint16)data[172] + \
            ((uint16)data[173] << 8));
        pTLookupTable1D_FiP16_RAM->Table[87] = UINT16_TO_INT16((uint16)data[174] + \
            ((uint16)data[175] << 8));
        pTLookupTable1D_FiP16_RAM->Table[88] = UINT16_TO_INT16((uint16)data[176] + \
            ((uint16)data[177] << 8));
        pTLookupTable1D_FiP16_RAM->Table[89] = UINT16_TO_INT16((uint16)data[178] + \
            ((uint16)data[179] << 8));
        pTLookupTable1D_FiP16_RAM->Table[90] = UINT16_TO_INT16((uint16)data[180] + \
            ((uint16)data[181] << 8));
        pTLookupTable1D_FiP16_RAM->Table[91] = UINT16_TO_INT16((uint16)data[182] + \
            ((uint16)data[183] << 8));
        pTLookupTable1D_FiP16_RAM->Table[92] = UINT16_TO_INT16((uint16)data[184] + \
            ((uint16)data[185] << 8));
        pTLookupTable1D_FiP16_RAM->Table[93] = UINT16_TO_INT16((uint16)data[186] + \
            ((uint16)data[187] << 8));
        pTLookupTable1D_FiP16_RAM->Table[94] = UINT16_TO_INT16((uint16)data[188] + \
            ((uint16)data[189] << 8));
        pTLookupTable1D_FiP16_RAM->Table[95] = UINT16_TO_INT16((uint16)data[190] + \
            ((uint16)data[191] << 8));
        pTLookupTable1D_FiP16_RAM->Table[96] = UINT16_TO_INT16((uint16)data[192] + \
            ((uint16)data[193] << 8));
        pTLookupTable1D_FiP16_RAM->Table[97] = UINT16_TO_INT16((uint16)data[194] + \
            ((uint16)data[195] << 8));
        pTLookupTable1D_FiP16_RAM->Table[98] = UINT16_TO_INT16((uint16)data[196] + \
            ((uint16)data[197] << 8));
        pTLookupTable1D_FiP16_RAM->Table[99] = UINT16_TO_INT16((uint16)data[198] + \
            ((uint16)data[199] << 8));
        pTLookupTable1D_FiP16_RAM->Table[100] = UINT16_TO_INT16((uint16)data[200] + \
            ((uint16)data[201] << 8));
        pTLookupTable1D_FiP16_RAM->Table[101] = UINT16_TO_INT16((uint16)data[202] + \
            ((uint16)data[203] << 8));
        pTLookupTable1D_FiP16_RAM->Table[102] = UINT16_TO_INT16((uint16)data[204] + \
            ((uint16)data[205] << 8));
        pTLookupTable1D_FiP16_RAM->Table[103] = UINT16_TO_INT16((uint16)data[206] + \
            ((uint16)data[207] << 8));
        pTLookupTable1D_FiP16_RAM->Table[104] = UINT16_TO_INT16((uint16)data[208] + \
            ((uint16)data[209] << 8));
        pTLookupTable1D_FiP16_RAM->Table[105] = UINT16_TO_INT16((uint16)data[210] + \
            ((uint16)data[211] << 8));
        pTLookupTable1D_FiP16_RAM->Table[106] = UINT16_TO_INT16((uint16)data[212] + \
            ((uint16)data[213] << 8));
        pTLookupTable1D_FiP16_RAM->Table[107] = UINT16_TO_INT16((uint16)data[214] + \
            ((uint16)data[215] << 8));
        pTLookupTable1D_FiP16_RAM->Table[108] = UINT16_TO_INT16((uint16)data[216] + \
            ((uint16)data[217] << 8));
        pTLookupTable1D_FiP16_RAM->Table[109] = UINT16_TO_INT16((uint16)data[218] + \
            ((uint16)data[219] << 8));
        pTLookupTable1D_FiP16_RAM->Table[110] = UINT16_TO_INT16((uint16)data[220] + \
            ((uint16)data[221] << 8));
        pTLookupTable1D_FiP16_RAM->Table[111] = UINT16_TO_INT16((uint16)data[222] + \
            ((uint16)data[223] << 8));
        pTLookupTable1D_FiP16_RAM->Table[112] = UINT16_TO_INT16((uint16)data[224] + \
            ((uint16)data[225] << 8));
        pTLookupTable1D_FiP16_RAM->Table[113] = UINT16_TO_INT16((uint16)data[226] + \
            ((uint16)data[227] << 8));
        pTLookupTable1D_FiP16_RAM->Table[114] = UINT16_TO_INT16((uint16)data[228] + \
            ((uint16)data[229] << 8));
        pTLookupTable1D_FiP16_RAM->Table[115] = UINT16_TO_INT16((uint16)data[230] + \
            ((uint16)data[231] << 8));
        pTLookupTable1D_FiP16_RAM->Table[116] = UINT16_TO_INT16((uint16)data[232] + \
            ((uint16)data[233] << 8));
        pTLookupTable1D_FiP16_RAM->Table[117] = UINT16_TO_INT16((uint16)data[234] + \
            ((uint16)data[235] << 8));
        pTLookupTable1D_FiP16_RAM->Table[118] = UINT16_TO_INT16((uint16)data[236] + \
            ((uint16)data[237] << 8));
        pTLookupTable1D_FiP16_RAM->Table[119] = UINT16_TO_INT16((uint16)data[238] + \
            ((uint16)data[239] << 8));
        pTLookupTable1D_FiP16_RAM->Table[120] = UINT16_TO_INT16((uint16)data[240] + \
            ((uint16)data[241] << 8));
        pTLookupTable1D_FiP16_RAM->Table[121] = UINT16_TO_INT16((uint16)data[242] + \
            ((uint16)data[243] << 8));
        pTLookupTable1D_FiP16_RAM->Table[122] = UINT16_TO_INT16((uint16)data[244] + \
            ((uint16)data[245] << 8));
        pTLookupTable1D_FiP16_RAM->Table[123] = UINT16_TO_INT16((uint16)data[246] + \
            ((uint16)data[247] << 8));
        pTLookupTable1D_FiP16_RAM->Table[124] = UINT16_TO_INT16((uint16)data[248] + \
            ((uint16)data[249] << 8));
        pTLookupTable1D_FiP16_RAM->Table[125] = UINT16_TO_INT16((uint16)data[250] + \
            ((uint16)data[251] << 8));
        pTLookupTable1D_FiP16_RAM->Table[126] = UINT16_TO_INT16((uint16)data[252] + \
            ((uint16)data[253] << 8));
        pTLookupTable1D_FiP16_RAM->Table[127] = UINT16_TO_INT16((uint16)data[254] + \
            ((uint16)data[255] << 8));
        pTLookupTable1D_FiP16_RAM->Table[128] = UINT16_TO_INT16((uint16)data[256] + \
            ((uint16)data[257] << 8));
        pTLookupTable1D_FiP16_RAM->Table[129] = UINT16_TO_INT16((uint16)data[258] + \
            ((uint16)data[259] << 8));
        pTLookupTable1D_FiP16_RAM->Table[130] = UINT16_TO_INT16((uint16)data[260] + \
            ((uint16)data[261] << 8));
        pTLookupTable1D_FiP16_RAM->Table[131] = UINT16_TO_INT16((uint16)data[262] + \
            ((uint16)data[263] << 8));
        pTLookupTable1D_FiP16_RAM->Table[132] = UINT16_TO_INT16((uint16)data[264] + \
            ((uint16)data[265] << 8));
        pTLookupTable1D_FiP16_RAM->Table[133] = UINT16_TO_INT16((uint16)data[266] + \
            ((uint16)data[267] << 8));
        pTLookupTable1D_FiP16_RAM->Table[134] = UINT16_TO_INT16((uint16)data[268] + \
            ((uint16)data[269] << 8));
        pTLookupTable1D_FiP16_RAM->Table[135] = UINT16_TO_INT16((uint16)data[270] + \
            ((uint16)data[271] << 8));
        pTLookupTable1D_FiP16_RAM->Table[136] = UINT16_TO_INT16((uint16)data[272] + \
            ((uint16)data[273] << 8));
        pTLookupTable1D_FiP16_RAM->Table[137] = UINT16_TO_INT16((uint16)data[274] + \
            ((uint16)data[275] << 8));
        pTLookupTable1D_FiP16_RAM->Table[138] = UINT16_TO_INT16((uint16)data[276] + \
            ((uint16)data[277] << 8));
        pTLookupTable1D_FiP16_RAM->Table[139] = UINT16_TO_INT16((uint16)data[278] + \
            ((uint16)data[279] << 8));
        pTLookupTable1D_FiP16_RAM->Table[140] = UINT16_TO_INT16((uint16)data[280] + \
            ((uint16)data[281] << 8));
        pTLookupTable1D_FiP16_RAM->Table[141] = UINT16_TO_INT16((uint16)data[282] + \
            ((uint16)data[283] << 8));
        pTLookupTable1D_FiP16_RAM->Table[142] = UINT16_TO_INT16((uint16)data[284] + \
            ((uint16)data[285] << 8));
        pTLookupTable1D_FiP16_RAM->Table[143] = UINT16_TO_INT16((uint16)data[286] + \
            ((uint16)data[287] << 8));
        pTLookupTable1D_FiP16_RAM->Table[144] = UINT16_TO_INT16((uint16)data[288] + \
            ((uint16)data[289] << 8));
        pTLookupTable1D_FiP16_RAM->Table[145] = UINT16_TO_INT16((uint16)data[290] + \
            ((uint16)data[291] << 8));
        pTLookupTable1D_FiP16_RAM->Table[146] = UINT16_TO_INT16((uint16)data[292] + \
            ((uint16)data[293] << 8));
        pTLookupTable1D_FiP16_RAM->Table[147] = UINT16_TO_INT16((uint16)data[294] + \
            ((uint16)data[295] << 8));
        pTLookupTable1D_FiP16_RAM->Table[148] = UINT16_TO_INT16((uint16)data[296] + \
            ((uint16)data[297] << 8));
        pTLookupTable1D_FiP16_RAM->Table[149] = UINT16_TO_INT16((uint16)data[298] + \
            ((uint16)data[299] << 8));
        pTLookupTable1D_FiP16_RAM->Table[150] = UINT16_TO_INT16((uint16)data[300] + \
            ((uint16)data[301] << 8));
        pTLookupTable1D_FiP16_RAM->Table[151] = UINT16_TO_INT16((uint16)data[302] + \
            ((uint16)data[303] << 8));
        pTLookupTable1D_FiP16_RAM->Table[152] = UINT16_TO_INT16((uint16)data[304] + \
            ((uint16)data[305] << 8));
        pTLookupTable1D_FiP16_RAM->Table[153] = UINT16_TO_INT16((uint16)data[306] + \
            ((uint16)data[307] << 8));
        pTLookupTable1D_FiP16_RAM->Table[154] = UINT16_TO_INT16((uint16)data[308] + \
            ((uint16)data[309] << 8));
        pTLookupTable1D_FiP16_RAM->Table[155] = UINT16_TO_INT16((uint16)data[310] + \
            ((uint16)data[311] << 8));
        pTLookupTable1D_FiP16_RAM->Table[156] = UINT16_TO_INT16((uint16)data[312] + \
            ((uint16)data[313] << 8));
        pTLookupTable1D_FiP16_RAM->Table[157] = UINT16_TO_INT16((uint16)data[314] + \
            ((uint16)data[315] << 8));
        pTLookupTable1D_FiP16_RAM->Table[158] = UINT16_TO_INT16((uint16)data[316] + \
            ((uint16)data[317] << 8));
        pTLookupTable1D_FiP16_RAM->Table[159] = UINT16_TO_INT16((uint16)data[318] + \
            ((uint16)data[319] << 8));
        pTLookupTable1D_FiP16_RAM->Table[160] = UINT16_TO_INT16((uint16)data[320] + \
            ((uint16)data[321] << 8));
        pTLookupTable1D_FiP16_RAM->Table[161] = UINT16_TO_INT16((uint16)data[322] + \
            ((uint16)data[323] << 8));
        pTLookupTable1D_FiP16_RAM->Table[162] = UINT16_TO_INT16((uint16)data[324] + \
            ((uint16)data[325] << 8));
        pTLookupTable1D_FiP16_RAM->Table[163] = UINT16_TO_INT16((uint16)data[326] + \
            ((uint16)data[327] << 8));
        pTLookupTable1D_FiP16_RAM->Table[164] = UINT16_TO_INT16((uint16)data[328] + \
            ((uint16)data[329] << 8));
        pTLookupTable1D_FiP16_RAM->Table[165] = UINT16_TO_INT16((uint16)data[330] + \
            ((uint16)data[331] << 8));
        pTLookupTable1D_FiP16_RAM->Table[166] = UINT16_TO_INT16((uint16)data[332] + \
            ((uint16)data[333] << 8));
        pTLookupTable1D_FiP16_RAM->Table[167] = UINT16_TO_INT16((uint16)data[334] + \
            ((uint16)data[335] << 8));
        pTLookupTable1D_FiP16_RAM->Table[168] = UINT16_TO_INT16((uint16)data[336] + \
            ((uint16)data[337] << 8));
        pTLookupTable1D_FiP16_RAM->Table[169] = UINT16_TO_INT16((uint16)data[338] + \
            ((uint16)data[339] << 8));
        pTLookupTable1D_FiP16_RAM->Table[170] = UINT16_TO_INT16((uint16)data[340] + \
            ((uint16)data[341] << 8));
        pTLookupTable1D_FiP16_RAM->Table[171] = UINT16_TO_INT16((uint16)data[342] + \
            ((uint16)data[343] << 8));
        pTLookupTable1D_FiP16_RAM->Table[172] = UINT16_TO_INT16((uint16)data[344] + \
            ((uint16)data[345] << 8));
        pTLookupTable1D_FiP16_RAM->Table[173] = UINT16_TO_INT16((uint16)data[346] + \
            ((uint16)data[347] << 8));
        pTLookupTable1D_FiP16_RAM->Table[174] = UINT16_TO_INT16((uint16)data[348] + \
            ((uint16)data[349] << 8));
        pTLookupTable1D_FiP16_RAM->Table[175] = UINT16_TO_INT16((uint16)data[350] + \
            ((uint16)data[351] << 8));
        pTLookupTable1D_FiP16_RAM->Table[176] = UINT16_TO_INT16((uint16)data[352] + \
            ((uint16)data[353] << 8));
        pTLookupTable1D_FiP16_RAM->Table[177] = UINT16_TO_INT16((uint16)data[354] + \
            ((uint16)data[355] << 8));
        pTLookupTable1D_FiP16_RAM->Table[178] = UINT16_TO_INT16((uint16)data[356] + \
            ((uint16)data[357] << 8));
        pTLookupTable1D_FiP16_RAM->Table[179] = UINT16_TO_INT16((uint16)data[358] + \
            ((uint16)data[359] << 8));
        pTLookupTable1D_FiP16_RAM->Table[180] = UINT16_TO_INT16((uint16)data[360] + \
            ((uint16)data[361] << 8));
        pTLookupTable1D_FiP16_RAM->Table[181] = UINT16_TO_INT16((uint16)data[362] + \
            ((uint16)data[363] << 8));
        pTLookupTable1D_FiP16_RAM->Table[182] = UINT16_TO_INT16((uint16)data[364] + \
            ((uint16)data[365] << 8));
        pTLookupTable1D_FiP16_RAM->Table[183] = UINT16_TO_INT16((uint16)data[366] + \
            ((uint16)data[367] << 8));
        pTLookupTable1D_FiP16_RAM->Table[184] = UINT16_TO_INT16((uint16)data[368] + \
            ((uint16)data[369] << 8));
        pTLookupTable1D_FiP16_RAM->Table[185] = UINT16_TO_INT16((uint16)data[370] + \
            ((uint16)data[371] << 8));
        pTLookupTable1D_FiP16_RAM->Table[186] = UINT16_TO_INT16((uint16)data[372] + \
            ((uint16)data[373] << 8));
        pTLookupTable1D_FiP16_RAM->Table[187] = UINT16_TO_INT16((uint16)data[374] + \
            ((uint16)data[375] << 8));
        pTLookupTable1D_FiP16_RAM->Table[188] = UINT16_TO_INT16((uint16)data[376] + \
            ((uint16)data[377] << 8));
        pTLookupTable1D_FiP16_RAM->Table[189] = UINT16_TO_INT16((uint16)data[378] + \
            ((uint16)data[379] << 8));
        pTLookupTable1D_FiP16_RAM->Table[190] = UINT16_TO_INT16((uint16)data[380] + \
            ((uint16)data[381] << 8));
        pTLookupTable1D_FiP16_RAM->Table[191] = UINT16_TO_INT16((uint16)data[382] + \
            ((uint16)data[383] << 8));
        pTLookupTable1D_FiP16_RAM->Table[192] = UINT16_TO_INT16((uint16)data[384] + \
            ((uint16)data[385] << 8));
        pTLookupTable1D_FiP16_RAM->Table[193] = UINT16_TO_INT16((uint16)data[386] + \
            ((uint16)data[387] << 8));
        pTLookupTable1D_FiP16_RAM->Table[194] = UINT16_TO_INT16((uint16)data[388] + \
            ((uint16)data[389] << 8));
        pTLookupTable1D_FiP16_RAM->Table[195] = UINT16_TO_INT16((uint16)data[390] + \
            ((uint16)data[391] << 8));
        pTLookupTable1D_FiP16_RAM->Table[196] = UINT16_TO_INT16((uint16)data[392] + \
            ((uint16)data[393] << 8));
        pTLookupTable1D_FiP16_RAM->Table[197] = UINT16_TO_INT16((uint16)data[394] + \
            ((uint16)data[395] << 8));
        pTLookupTable1D_FiP16_RAM->Table[198] = UINT16_TO_INT16((uint16)data[396] + \
            ((uint16)data[397] << 8));
        pTLookupTable1D_FiP16_RAM->Table[199] = UINT16_TO_INT16((uint16)data[398] + \
            ((uint16)data[399] << 8));
        pTLookupTable1D_FiP16_RAM->Table[200] = UINT16_TO_INT16((uint16)data[400] + \
            ((uint16)data[401] << 8));
        pTLookupTable1D_FiP16_RAM->Table[201] = UINT16_TO_INT16((uint16)data[402] + \
            ((uint16)data[403] << 8));
        pTLookupTable1D_FiP16_RAM->Table[202] = UINT16_TO_INT16((uint16)data[404] + \
            ((uint16)data[405] << 8));
        pTLookupTable1D_FiP16_RAM->Table[203] = UINT16_TO_INT16((uint16)data[406] + \
            ((uint16)data[407] << 8));
        pTLookupTable1D_FiP16_RAM->Table[204] = UINT16_TO_INT16((uint16)data[408] + \
            ((uint16)data[409] << 8));
        pTLookupTable1D_FiP16_RAM->Table[205] = UINT16_TO_INT16((uint16)data[410] + \
            ((uint16)data[411] << 8));
        pTLookupTable1D_FiP16_RAM->Table[206] = UINT16_TO_INT16((uint16)data[412] + \
            ((uint16)data[413] << 8));
        pTLookupTable1D_FiP16_RAM->Table[207] = UINT16_TO_INT16((uint16)data[414] + \
            ((uint16)data[415] << 8));
        pTLookupTable1D_FiP16_RAM->Table[208] = UINT16_TO_INT16((uint16)data[416] + \
            ((uint16)data[417] << 8));
        pTLookupTable1D_FiP16_RAM->Table[209] = UINT16_TO_INT16((uint16)data[418] + \
            ((uint16)data[419] << 8));
        pTLookupTable1D_FiP16_RAM->Table[210] = UINT16_TO_INT16((uint16)data[420] + \
            ((uint16)data[421] << 8));
        pTLookupTable1D_FiP16_RAM->Table[211] = UINT16_TO_INT16((uint16)data[422] + \
            ((uint16)data[423] << 8));
        pTLookupTable1D_FiP16_RAM->Table[212] = UINT16_TO_INT16((uint16)data[424] + \
            ((uint16)data[425] << 8));
        pTLookupTable1D_FiP16_RAM->Table[213] = UINT16_TO_INT16((uint16)data[426] + \
            ((uint16)data[427] << 8));
        pTLookupTable1D_FiP16_RAM->Table[214] = UINT16_TO_INT16((uint16)data[428] + \
            ((uint16)data[429] << 8));
        pTLookupTable1D_FiP16_RAM->Table[215] = UINT16_TO_INT16((uint16)data[430] + \
            ((uint16)data[431] << 8));
        pTLookupTable1D_FiP16_RAM->Table[216] = UINT16_TO_INT16((uint16)data[432] + \
            ((uint16)data[433] << 8));
        pTLookupTable1D_FiP16_RAM->Table[217] = UINT16_TO_INT16((uint16)data[434] + \
            ((uint16)data[435] << 8));
        pTLookupTable1D_FiP16_RAM->Table[218] = UINT16_TO_INT16((uint16)data[436] + \
            ((uint16)data[437] << 8));
        pTLookupTable1D_FiP16_RAM->Table[219] = UINT16_TO_INT16((uint16)data[438] + \
            ((uint16)data[439] << 8));
        pTLookupTable1D_FiP16_RAM->Table[220] = UINT16_TO_INT16((uint16)data[440] + \
            ((uint16)data[441] << 8));
        pTLookupTable1D_FiP16_RAM->Table[221] = UINT16_TO_INT16((uint16)data[442] + \
            ((uint16)data[443] << 8));
        pTLookupTable1D_FiP16_RAM->Table[222] = UINT16_TO_INT16((uint16)data[444] + \
            ((uint16)data[445] << 8));
        pTLookupTable1D_FiP16_RAM->Table[223] = UINT16_TO_INT16((uint16)data[446] + \
            ((uint16)data[447] << 8));
        pTLookupTable1D_FiP16_RAM->Table[224] = UINT16_TO_INT16((uint16)data[448] + \
            ((uint16)data[449] << 8));
        pTLookupTable1D_FiP16_RAM->Table[225] = UINT16_TO_INT16((uint16)data[450] + \
            ((uint16)data[451] << 8));
        pTLookupTable1D_FiP16_RAM->Table[226] = UINT16_TO_INT16((uint16)data[452] + \
            ((uint16)data[453] << 8));
        pTLookupTable1D_FiP16_RAM->Table[227] = UINT16_TO_INT16((uint16)data[454] + \
            ((uint16)data[455] << 8));
        pTLookupTable1D_FiP16_RAM->Table[228] = UINT16_TO_INT16((uint16)data[456] + \
            ((uint16)data[457] << 8));
        pTLookupTable1D_FiP16_RAM->Table[229] = UINT16_TO_INT16((uint16)data[458] + \
            ((uint16)data[459] << 8));
        pTLookupTable1D_FiP16_RAM->Table[230] = UINT16_TO_INT16((uint16)data[460] + \
            ((uint16)data[461] << 8));
        pTLookupTable1D_FiP16_RAM->Table[231] = UINT16_TO_INT16((uint16)data[462] + \
            ((uint16)data[463] << 8));
        pTLookupTable1D_FiP16_RAM->Table[232] = UINT16_TO_INT16((uint16)data[464] + \
            ((uint16)data[465] << 8));
        pTLookupTable1D_FiP16_RAM->Table[233] = UINT16_TO_INT16((uint16)data[466] + \
            ((uint16)data[467] << 8));
        pTLookupTable1D_FiP16_RAM->Table[234] = UINT16_TO_INT16((uint16)data[468] + \
            ((uint16)data[469] << 8));
        pTLookupTable1D_FiP16_RAM->Table[235] = UINT16_TO_INT16((uint16)data[470] + \
            ((uint16)data[471] << 8));
        pTLookupTable1D_FiP16_RAM->Table[236] = UINT16_TO_INT16((uint16)data[472] + \
            ((uint16)data[473] << 8));
        pTLookupTable1D_FiP16_RAM->Table[237] = UINT16_TO_INT16((uint16)data[474] + \
            ((uint16)data[475] << 8));
        pTLookupTable1D_FiP16_RAM->Table[238] = UINT16_TO_INT16((uint16)data[476] + \
            ((uint16)data[477] << 8));
        pTLookupTable1D_FiP16_RAM->Table[239] = UINT16_TO_INT16((uint16)data[478] + \
            ((uint16)data[479] << 8));
        pTLookupTable1D_FiP16_RAM->Table[240] = UINT16_TO_INT16((uint16)data[480] + \
            ((uint16)data[481] << 8));
        pTLookupTable1D_FiP16_RAM->Table[241] = UINT16_TO_INT16((uint16)data[482] + \
            ((uint16)data[483] << 8));
        pTLookupTable1D_FiP16_RAM->Table[242] = UINT16_TO_INT16((uint16)data[484] + \
            ((uint16)data[485] << 8));
        pTLookupTable1D_FiP16_RAM->Table[243] = UINT16_TO_INT16((uint16)data[486] + \
            ((uint16)data[487] << 8));
        pTLookupTable1D_FiP16_RAM->Table[244] = UINT16_TO_INT16((uint16)data[488] + \
            ((uint16)data[489] << 8));
        pTLookupTable1D_FiP16_RAM->Table[245] = UINT16_TO_INT16((uint16)data[490] + \
            ((uint16)data[491] << 8));
        pTLookupTable1D_FiP16_RAM->Table[246] = UINT16_TO_INT16((uint16)data[492] + \
            ((uint16)data[493] << 8));
        pTLookupTable1D_FiP16_RAM->Table[247] = UINT16_TO_INT16((uint16)data[494] + \
            ((uint16)data[495] << 8));
        pTLookupTable1D_FiP16_RAM->Table[248] = UINT16_TO_INT16((uint16)data[496] + \
            ((uint16)data[497] << 8));
        pTLookupTable1D_FiP16_RAM->Table[249] = UINT16_TO_INT16((uint16)data[498] + \
            ((uint16)data[499] << 8));
        pTLookupTable1D_FiP16_RAM->Table[250] = UINT16_TO_INT16((uint16)data[500] + \
            ((uint16)data[501] << 8));
        pTLookupTable1D_FiP16_RAM->Table[251] = UINT16_TO_INT16((uint16)data[502] + \
            ((uint16)data[503] << 8));
        pTLookupTable1D_FiP16_RAM->Table[252] = UINT16_TO_INT16((uint16)data[504] + \
            ((uint16)data[505] << 8));
        pTLookupTable1D_FiP16_RAM->Table[253] = UINT16_TO_INT16((uint16)data[506] + \
            ((uint16)data[507] << 8));
        pTLookupTable1D_FiP16_RAM->Table[254] = UINT16_TO_INT16((uint16)data[508] + \
            ((uint16)data[509] << 8));
        pTLookupTable1D_FiP16_RAM->Table[255] = UINT16_TO_INT16((uint16)data[510] + \
            ((uint16)data[511] << 8));
        pTLookupTable1D_FiP16_RAM->Table[256] = UINT16_TO_INT16((uint16)data[512] + \
            ((uint16)data[513] << 8));
        pTLookupTable1D_FiP16_RAM->sfrX = UINT8_TO_INT8((uint8)data[514]);
        pTLookupTable1D_FiP16_RAM->maskX = ((uint16)data[515] + \
            ((uint16)data[516] << 8));
        pTLookupTable1D_FiP16_RAM->idxOffsetX = ((uint16)data[517] + \
            ((uint16)data[518] << 8));
        pTLookupTable1D_FiP16_RAM->gainX = UINT16_TO_INT16((uint16)data[519] + \
            ((uint16)data[520] << 8));
        pTLookupTable1D_FiP16_RAM->gainXsfr = UINT8_TO_INT8((uint8)data[521]);
        pTLookupTable1D_FiP16_RAM->offsetX = UINT16_TO_INT16((uint16)data[522] + \
            ((uint16)data[523] << 8));
        pTLookupTable1D_FiP16_RAM->minX = UINT16_TO_INT16((uint16)data[524] + \
            ((uint16)data[525] << 8));
        pTLookupTable1D_FiP16_RAM->maxX = UINT16_TO_INT16((uint16)data[526] + \
            ((uint16)data[527] << 8));
        error = (uint8)0;
/* USERCODE-BEGIN:SaveFnc                                                                                             */
/* USERCODE-END:SaveFnc                                                                                               */
    }
    return (error);
}

/**********************************************************************************************************************/
/** Get block element address                                                                                        **/
/**********************************************************************************************************************/
#if !defined(LOOKUPTABLE1D_FIP16_RAM_ISLINKED)
void* LookupTable1D_FiP16_RAM_GetAddress(const LOOKUPTABLE1D_FIP16_RAM* block, uint16 elementId)
{
    void* addr;
    switch (elementId)
    {
        case 1:
            addr = (void*)block->x;
            break;
        case 2:
            addr = (void*)&block->Out;
            break;
        default:
            addr = (void*)0;
            break;
    }
    return (addr);
}
#endif
