// Copyright (c) 2021, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
// All rights reserved.
//
// This file is licensed according to the BSD 3-clause license as follows:
// 
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//     * Redistributions of source code must retain the above copyright
//       notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above copyright
//       notice, this list of conditions and the following disclaimer in the
//       documentation and/or other materials provided with the distribution.
//     * Neither the name of the "Linz Center of Mechatronics GmbH" and "LCM" nor
//       the names of its contributors may be used to endorse or promote products
//       derived from this software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
// IN NO EVENT SHALL "Linz Center of Mechatronics GmbH" BE LIABLE FOR ANY
// DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
// (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
// LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
// ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//
// This file is part of X2C. http://x2c.lcm.at/
// $LastChangedRevision: 1733 $
// $LastChangedDate:: 2019-08-29 09:41:24 +0200#$
//
// Function converts a string containing key-value pairs (key=value) separated by semicolons into a structure.
// Example: string = 'member1=55;member2=66' is converted into a structure containing members:
// - member1 with value '55' (string type)
// - member2 with value '66' (string type)
// 
// Parameters:
// val_string ... String containing key-value pairs
// source_struct (optional) ... existing structure which will be modified by the members being contained in val_string

function [val_struct] = string2struct(val_string, source_struct)
    funcprot(0);
    
    // separator between pairs
    pair_sep = ";";
    // separator between key and value
    keyval_sep = "=";
    
    // create new structure or use existing source structure
    if isdef("source_struct", "l") then
        val_struct = source_struct;
    else
        val_struct = struct();
    end
    
    // get all key-value pairs
    pairs = tokens(val_string, pair_sep);
    
    for i = 1:size(pairs, 1)
        cur_pair = pairs(i);
        keyval_pair_string = tokens(cur_pair, keyval_sep);
        // process valid key-value pairs only
        if size(keyval_pair_string, 1) >= 2 then
            // removes possible leading and trailing blanks from key
            key = stripblanks(keyval_pair_string(1));
            value = strcat(keyval_pair_string(2:$), keyval_sep);
        elseif (size(keyval_pair_string, 1) == 1) & (part(cur_pair, $) == keyval_sep) then
            // special handling if a key-value pair contains an empty value (e.g. 'mykey=')
            key = stripblanks(keyval_pair_string(1));
            value = '';
        else
            // next iteration without adding current pair to structure
            mprintf("Skip invalid pair %d : %s\n", i, cur_pair);
            continue;
        end
        execstr('val_struct.' + key + ' = ''' + value + ''';');
    end
endfunction
